/*
 * Copyright (c) 2001-2002 The Trustees of Indiana University.  
 *                         All rights reserved.
 * Copyright (c) 1998-2001 University of Notre Dame. 
 *                         All rights reserved.
 * Copyright (c) 1994-1998 The Ohio State University.  
 *                         All rights reserved.
 * 
 * This file is part of the LAM/MPI software package.  For license
 * information, see the LICENSE file in the top level directory of the
 * LAM/MPI source distribution.
 * 
 *
 * $Id: alltoall.c,v 1.2.2.1 2002/10/09 19:48:31 brbarret Exp $
 *
 * Example program that sends a message from each node each other node
 * in a blocking pattern.
 */

#include <stdio.h>
#include "mpi.h"

#define MSGSZ 32*1024
int
main(int argc, char* argv[])
{
  int i,j;
  int msg[MSGSZ];
  int rank;
  int size;
  int tag = 201;
  int receive_message[MSGSZ];
  MPI_Request req; 
  /* Normal MPI startup */

  MPI_Init(&argc, &argv);
  MPI_Comm_size(MPI_COMM_WORLD, &size);
  MPI_Comm_rank(MPI_COMM_WORLD, &rank);

  /* Check to ensure that we have 2 ranks */

  if (size < 2) {
    printf("This program must be run with 2 or more ranks.\n");
    MPI_Finalize();
    return 1;
  }

  msg[0] = rank;
  for (j=0;j<5;j++){
  for (i = 0; i < size; i++) {
    if (i == rank) {

      /* Skip communicating with myself */

      printf("Rank %d not sending to myself\n", i);
      continue;
    } else {


      printf("Rank %d sending message \"%d\" to rank %d\n",
	     rank, rank, i);
      msg[0] = rank;
      MPI_Isend(msg, MSGSZ, MPI_INT, i, tag, MPI_COMM_WORLD,&req);
      MPI_Recv(receive_message, MSGSZ, MPI_INT, i, tag, MPI_COMM_WORLD, 
	       MPI_STATUS_IGNORE);
      printf("Rank %d received message \"%d\" from rank %d\n",
	     rank, receive_message[0], i);
    }
  }
  }

  /* All done */

  printf("Rank %d finished\n", rank);
  MPI_Finalize();
  return 0;
}
